pycocoa.panels

Package pycocoa :: Module panels |
[frames] | no frames]

# Module panels

Types OpenPanel and SavePanel, wrapping ObjC `NSOpenPanel` and `NSSavePanel`.

Version: 25.03.16

Classes
| AlertPanel Python Type to show an alert, wrapping ObjC `NSAlert`.
| BrowserPanel Python Type to show a URL or file.
| ErrorPanel Python Type to show an `NSError` alert, wrapping ObjC `NSAlert`.
| OpenPanel Python Type to select a file, wrapping ObjC `NSOpenPanel`.
| SavePanel Python Type to save a file, wrapping ObjC `NSSavePanel`.
| TextPanel Scrollable text panel Python Type, wrapping ObjC `NSAlert`.

Variables
| __all__ = `_ALL_LAZY.panels`
| AlertStyle = `AlertStyle.Critical`...`` Alert level constants (`int`).
| NSAlertDelegate = `<pycocoa.internals.proxy_RO object at 0x7f81`...``
| PanelButton = `PanelButton.Cancel`...`` Panel button kinds (`int`).
| AlertStyle.Critical 2
| AlertStyle.Info 1
| AlertStyle.Informational 1
| AlertStyle.Warning 0
| PanelButton.Cancel 0
| PanelButton.Close 1
| PanelButton.Error -3
| PanelButton.OK 1
| PanelButton.Other 2
| PanelButton.Suppressed -2
| PanelButton.TimedOut -1

Variables Details

  ### AlertStyle Alert level constants (`int`). Value:
      AlertStyle.Critical=2,
                .Info=1,
                .Informational=1,
                .Warning=0

  ### NSAlertDelegate Value:
      <pycocoa.internals.proxy_RO object at 0x7f81384b2290>

  ### PanelButton Panel button kinds (`int`). Value:
      PanelButton.Cancel=0,
                 .Close=1,
                 .Error=-3,
                 .OK=1,
                 .Other=2,
                 .Suppressed=-2,
                 .TimedOut=-1